# == Define: sys::apt::sources
#
# Sets up a `sources.list` file for apt repositories.
#
# === Parameters
#
# [*repositories*]
#  Required.  List of hashes that specify the repository options.  Each
#  hash must have a 'uri', 'distribution', and 'components' keys.
#
# [*source*]
#  Whether to include source ('deb-src') repositories.  Defaults to true.
#
# [*template*]
#  Template to use to render the sources.list, defaults to
# 'sys/apt/sources.list.erb'.
#
# === Examples
#
# This resource declaration:
#
#    sys::apt::sources { '/etc/apt/sources.list':
#      repositories => [
#        { 'uri'          => 'http://us.archive.ubuntu.com/ubuntu/',
#          'distribution' => 'precise',
#          'components'   => ['main', 'restricted'],
#        }
#      ],
#      source       => false,
#    }
#
# Produces the following content at `/etc/apt/sources.list`:
#
#   # This file autogenerated by Puppet with sys::apt::sources.
#   deb http://us.archive.ubuntu.com/ubuntu/ precise main restricted
#
define sys::apt::sources(
  $repositories,
  $source        = true,
  $template      = 'sys/apt/sources.list.erb'
){
  # The name of the resource should be the path to the apt
  # sources list, e.g., '/etc/apt/sources.list'.
  file { $name:
    ensure  => file,
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => template($template),
  }
}
